@@ -215,11 +215,6 @@ cc_printers_panel_class_init (CcPrintersPanelClass *klass)
   panel_class->get_permission = cc_printers_panel_get_permission;
 }
 
-static void
-cc_printers_panel_class_finalize (CcPrintersPanelClass *klass)
-{
-}
-
 static void
 on_cups_notification (GDBusConnection *connection,
                       const char      *sender_name,
@@ -1039,8 +1034,8 @@ actualize_printers_list (CcPrintersPanel *self)
             paused = (g_strcmp0 (priv->dests[i].options[j].value, "5") == 0);
           else if (g_strcmp0 (priv->dests[i].options[j].name, "device-uri") == 0)
             device_uri = priv->dests[i].options[j].value;
-          else if (g_strcmp0 (priv->dests[i].options[i].name, "printer-type") == 0)
-            printer_type = atoi (priv->dests[i].options[i].value);
+          else if (g_strcmp0 (priv->dests[i].options[j].name, "printer-type") == 0)
+            printer_type = atoi (priv->dests[i].options[j].value);
         }
 
       if (priv->dests[i].is_default)
